@@ -36,7 +36,7 @@ compile_scss <- function(data, id = NULL) {
   gt_options_tbl <-
     within(
       gt_options_tbl, {
-        value[color_rows] = value[color_rows] <-
+        value[color_rows] <- value[color_rows] <-
           lapply(value[color_rows], html_color)
       }
     )
