@@ -22,14 +22,15 @@
 #------------------------------------------------------------------------------#
 
 
+# row_group_order() ------------------------------------------------------------
 #' Modify the ordering of any row groups
 #'
 #' @description
 #'
-#' We can modify the display order of any row groups in a **gt** object with the
-#' `row_group_order()` function. The `groups` argument takes a vector of row
-#' group ID values. After this function is invoked, the row groups will adhere
-#' to this revised ordering. It isn't necessary to provide all row ID values in
+#' We can modify the display order of any row groups in a **gt** object with
+#' `row_group_order()`. The `groups` argument takes a vector of row group ID
+#' values. After this function is invoked, the row groups will adhere to this
+#' revised ordering. It isn't necessary to provide all row ID values in
 #' `groups`, rather, what is provided will assume the specified ordering at the
 #' top of the table and the remaining row groups will follow in their original
 #' ordering.
@@ -94,12 +95,12 @@ row_group_order <- function(
   arrange_groups <- dt_row_groups_get(data = data)
 
   # Stop function if any value in `groups` doesn't match a group name
-  if (any(!groups %in% arrange_groups)) {
+  if (!all(groups %in% arrange_groups)) {
 
     cli::cli_abort(c(
       "All values given as `groups` must correspond to `group_id` values.",
       "*" = "The following `group_id` values can be
-      used {str_catalog(arrange_groups)}."
+      used {.str {arrange_groups}}."
     ))
   }
 
