@@ -1,10 +1,35 @@
+#------------------------------------------------------------------------------#
+#
+#                /$$
+#               | $$
+#     /$$$$$$  /$$$$$$
+#    /$$__  $$|_  $$_/
+#   | $$  \ $$  | $$
+#   | $$  | $$  | $$ /$$
+#   |  $$$$$$$  |  $$$$/
+#    \____  $$   \___/
+#    /$$  \ $$
+#   |  $$$$$$/
+#    \______/
+#
+#  This file is part of the 'rstudio/gt' project.
+#
+#  Copyright (c) 2018-2024 gt authors
+#
+#  For full copyright and license information, please look at
+#  https://gt.rstudio.com/LICENSE.html
+#
+#------------------------------------------------------------------------------#
+
+
+# rm_header() ------------------------------------------------------------------
 #' Remove the table header
 #'
 #' @description
 #'
 #' We can remove the table header from a **gt** table quite easily with
 #' `rm_header()`. The table header is an optional table part (positioned above
-#' the column labels) that can be added through the [tab_header()].
+#' the column labels) that can be added through [tab_header()].
 #'
 #' This function for removal is useful if you have received a **gt** table
 #' (perhaps through an API that returns **gt** objects) but would prefer that
@@ -23,7 +48,7 @@
 #' @section Examples:
 #'
 #' Let's use a subset of the [`gtcars`] dataset to create a **gt** table. A
-#' header part can be added with the [tab_header()] function; with that, we get
+#' header part can be added with [tab_header()]; with that, we get
 #' a title and a subtitle for the table.
 #'
 #' ```r
@@ -45,7 +70,7 @@
 #' }}
 #'
 #' If you decide that you don't want the header in the `gt_tbl` object, it can
-#' be removed with the `rm_header()` function.
+#' be removed with `rm_header()`.
 #'
 #' ```r
 #' rm_header(data = gt_tbl)
@@ -72,33 +97,29 @@ rm_header <- function(data) {
   dt_heading_init(data = data)
 }
 
+# rm_stubhead() ----------------------------------------------------------------
 #' Remove the stubhead label
 #'
 #' @description
 #'
 #' We can easily remove the stubhead label from a **gt** table with
 #' `rm_stubhead()`. The stubhead location only exists if there is a table stub
-#' and the text in that cell is added through the [tab_stubhead()] function.
+#' and the text in that cell is added with [tab_stubhead()].
 #'
 #' This function for removal is useful if you have received a **gt** table
 #' (perhaps through an API that returns **gt** objects) but would prefer that
 #' the table not contain any content in the stubhead. This function is safe to
 #' use even if there is no stubhead label in the input `gt_tbl` object.
 #'
-#' @param data *The gt table data object*
-#'
-#'   `obj:<gt_tbl>` // **required**
-#'
-#'   This is the **gt** table object that is commonly created through use of the
-#'   [gt()] function.
+#' @inheritParams rm_header
 #'
 #' @return An object of class `gt_tbl`.
 #'
 #' @section Examples:
 #'
-#' Using the [`gtcars`] datset, we'll create a **gt** table. With the
-#' [tab_stubhead()] function, it's possible to add a stubhead label. This
-#' appears in the top-left and can be used to describe what is in the stub.
+#' Using the [`gtcars`] dataset, we'll create a **gt** table. With
+#' [tab_stubhead()], it's possible to add a stubhead label. This appears in the
+#' top-left and can be used to describe what is in the stub.
 #'
 #' ```r
 #' gt_tbl <-
@@ -116,7 +137,7 @@ rm_header <- function(data) {
 #' }}
 #'
 #' If you decide that you don't want the stubhead label in the `gt_tbl` object,
-#' it can be removed with the `rm_stubhead()` function.
+#' it can be removed with `rm_stubhead()`.
 #'
 #' ```r
 #' rm_stubhead(data = gt_tbl)
@@ -143,13 +164,14 @@ rm_stubhead <- function(data) {
   dt_stubhead_init(data = data)
 }
 
+# rm_spanners() ----------------------------------------------------------------
 #' Remove column spanner labels
 #'
 #' @description
 #'
 #' If you would like to remove column spanner labels then the `rm_spanners()`
 #' function can make this possible. Column spanner labels appear above the
-#' column labels and can occupy several levels via stacking either though
+#' column labels and can occupy several levels via stacking either through
 #' [tab_spanner()] or [tab_spanner_delim()]. Spanner column labels are
 #' distinguishable and accessible by their ID values.
 #'
@@ -160,12 +182,7 @@ rm_stubhead <- function(data) {
 #' so long as select helpers (such as the default `everything()`) are used
 #' instead of explicit ID values.
 #'
-#' @param data *The gt table data object*
-#'
-#'   `obj:<gt_tbl>` // **required**
-#'
-#'   This is the **gt** table object that is commonly created through use of the
-#'   [gt()] function.
+#' @inheritParams rm_header
 #'
 #' @param spanners *Spanners to remove*
 #'
@@ -190,10 +207,10 @@ rm_stubhead <- function(data) {
 #'
 #' @section Examples:
 #'
-#' Use a portion of the [`gtcars`] dataset to create a **gt** table. With the
-#' [tab_spanner()] function, we can group several related columns together under
-#' a spanner column. In this example, that is done with several calls of
-#' [tab_spanner()] in order to create two levels of spanner column labels.
+#' Use a portion of the [`gtcars`] dataset to create a **gt** table. With
+#' [tab_spanner()], we can group several related columns together under a
+#' spanner column. In this example, that is done with several [tab_spanner()]
+#' calls in order to create two levels of spanner column labels.
 #'
 #' ```r
 #' gt_tbl <-
@@ -223,7 +240,7 @@ rm_stubhead <- function(data) {
 #' }}
 #'
 #' If you decide that you don't want any of the spanners in the `gt_tbl` object,
-#' they can all be removed with the `rm_spanners()` function.
+#' they can all be removed with `rm_spanners()`.
 #'
 #' ```r
 #' rm_spanners(data = gt_tbl)
@@ -301,7 +318,8 @@ rm_spanners <- function(
       as.integer(
         resolve_vector_i(
           expr = {{ spanners }},
-          vector = spanners_tbl[["spanner_id"]]
+          vector = spanners_tbl[["spanner_id"]],
+          "spanner"
         )
       )
 
@@ -312,7 +330,7 @@ rm_spanners <- function(
     # Ensure that `levels` is numeric vector
     if (!is.numeric(levels)) {
       cli::cli_abort(
-        "If using {levels} to remove spanners, it must be a numeric vector."
+        "If using {.arg levels} to remove spanners, it must be a numeric vector."
       )
     }
 
@@ -356,14 +374,15 @@ rm_spanners <- function(
   data
 }
 
+# rm_footnotes() ---------------------------------------------------------------
 #' Remove table footnotes
 #'
 #' @description
 #'
-#' If you have one or more footnotes that ought to be removed, the
-#' `rm_footnotes()` function allows for such a selective removal. The table
-#' footer is an optional table part that is positioned below the table body,
-#' containing areas for both the footnotes and source notes.
+#' If you have one or more footnotes that ought to be removed, `rm_footnotes()`
+#' allows for such a selective removal. The table footer is an optional table
+#' part that is positioned below the table body, containing areas for both the
+#' footnotes and source notes.
 #'
 #' This function for removal is useful if you have received a **gt** table
 #' (perhaps through an API that returns **gt** objects) but would prefer that
@@ -372,12 +391,7 @@ rm_spanners <- function(
 #' (such as the default `everything()`) are used instead of explicit integer
 #' values.
 #'
-#' @param data *The gt table data object*
-#'
-#'   `obj:<gt_tbl>` // **required**
-#'
-#'   This is the **gt** table object that is commonly created through use of the
-#'   [gt()] function.
+#' @inheritParams rm_header
 #'
 #' @param footnotes *Footnotes to remove*
 #'
@@ -394,7 +408,7 @@ rm_spanners <- function(
 #' @section Examples:
 #'
 #' Use a subset of the [`sza`] dataset to create a **gt** table. Color the `sza`
-#' column using the [data_color()] function, then, use [tab_footnote()] twice to
+#' column using [data_color()], then, use [tab_footnote()] twice to
 #' add two footnotes (each one targeting a different column label).
 #'
 #' ```r
@@ -438,7 +452,7 @@ rm_spanners <- function(
 #' }}
 #'
 #' If you decide that you don't want the footnotes in the `gt_tbl` object,
-#' they can be removed with the `rm_footnotes()` function.
+#' they can be removed with `rm_footnotes()`.
 #'
 #' ```r
 #' rm_footnotes(data = gt_tbl)
@@ -498,7 +512,8 @@ rm_footnotes <- function(
     as.integer(
       resolve_vector_i(
         expr = {{ footnotes }},
-        vector = as.character(seq_len(footnotes_count))
+        vector = as.character(seq_len(footnotes_count)),
+        "footnote"
       )
     )
 
@@ -528,14 +543,15 @@ rm_footnotes <- function(
   data
 }
 
+# rm_source_notes() ------------------------------------------------------------
 #' Remove table source notes
 #'
 #' @description
 #'
-#' If you have one or more source notes that ought to be removed, the
-#' `rm_source_notes()` function allows for such a selective removal. The table
-#' footer is an optional table part that is positioned below the table body,
-#' containing areas for both the source notes and footnotes.
+#' If you have one or more source notes that ought to be removed,
+#' `rm_source_notes()` allows for such a selective removal. The table footer is
+#' an optional table part that is positioned below the table body, containing
+#' areas for both the source notes and footnotes.
 #'
 #' This function for removal is useful if you have received a **gt** table
 #' (perhaps through an API that returns **gt** objects) but would prefer that
@@ -544,12 +560,7 @@ rm_footnotes <- function(
 #' helpers (such as the default `everything()`) are used instead of explicit
 #' integer values.
 #'
-#' @param data *The gt table data object*
-#'
-#'   `obj:<gt_tbl>` // **required**
-#'
-#'   This is the **gt** table object that is commonly created through use of the
-#'   [gt()] function.
+#' @inheritParams rm_header
 #'
 #' @param source_notes *Source notes to remove*
 #'
@@ -565,10 +576,10 @@ rm_footnotes <- function(
 #'
 #' @section Examples:
 #'
-#' Use a subset of the [`gtcars`] dataset to create a **gt** table. The
-#' [tab_source_note()] function is used to add a source note to the table footer
-#' that cites the data source (or, it could just be arbitrary text). We'll use
-#' the function twice, in effect adding two source notes to the footer.
+#' Use a subset of the [`gtcars`] dataset to create a **gt** table.
+#' [tab_source_note()] is used to add a source note to the table footer that
+#' cites the data source (or, it could just be arbitrary text). We'll use the
+#' function twice, in effect adding two source notes to the footer.
 #'
 #' ```r
 #' gt_tbl <-
@@ -588,7 +599,7 @@ rm_footnotes <- function(
 #' }}
 #'
 #' If you decide that you don't want the source notes in the `gt_tbl` object,
-#' they can be removed with the `rm_source_notes()` function.
+#' they can be removed with `rm_source_notes()`.
 #'
 #' ```r
 #' rm_source_notes(data = gt_tbl)
@@ -649,7 +660,8 @@ rm_source_notes <- function(
     as.integer(
       resolve_vector_i(
         expr = {{ source_notes }},
-        vector = as.character(seq_len(source_notes_length))
+        vector = as.character(seq_len(source_notes_length)),
+        "source note"
       )
     )
 
@@ -679,6 +691,7 @@ rm_source_notes <- function(
   data
 }
 
+# rm_caption() -----------------------------------------------------------------
 #' Remove the table caption
 #'
 #' @description
@@ -692,20 +705,15 @@ rm_source_notes <- function(
 #' the table not have a caption at all. This function is safe to use even if
 #' there is no table caption set in the input `gt_tbl` object.
 #'
-#' @param data *The gt table data object*
-#'
-#'   `obj:<gt_tbl>` // **required**
-#'
-#'   This is the **gt** table object that is commonly created through use of the
-#'   [gt()] function.
+#' @inheritParams rm_header
 #'
 #' @return An object of class `gt_tbl`.
 #'
 #' @section Examples:
 #'
 #' Use a portion of the [`gtcars`] dataset to create a **gt** table. We'll add a
-#' header part with the [tab_header()] function, and, a caption will also be
-#' added via the [tab_caption()] function.
+#' header part with [tab_header()], and, a caption will also be added via
+#' [tab_caption()].
 #'
 #' ```r
 #' gt_tbl <-
@@ -726,8 +734,8 @@ rm_source_notes <- function(
 #' `r man_get_image_tag(file = "man_rm_caption_1.png")`
 #' }}
 #'
-#' If you decide that you don't want the caption in the `gt_tbl` object,
-#' it can be removed with the `rm_caption()` function.
+#' If you decide that you don't want the caption in the `gt_tbl` object, it can
+#' be removed with `rm_caption()`.
 #'
 #' ```r
 #' rm_caption(data = gt_tbl)
