@@ -21,6 +21,7 @@
 #
 #------------------------------------------------------------------------------#
 
+
 #nocov start
 
 fetch_rd_db <- utils::getFromNamespace("fetchRdDB", "tools")
@@ -39,10 +40,9 @@ get_topic_names <- function() {
   # Exclude any topics that have `.` or `-` characters within their names,
   # and, exclude the 'pipe' and 'reexports' topic
   topic_names[
-    !grepl("\\.", topic_names) &
-      !grepl("-", topic_names) &
-      !grepl("^pipe$", topic_names) &
-      !grepl("^reexports$", topic_names)
+    !grepl(".", topic_names, fixed = TRUE) &
+      !grepl("-", topic_names, fixed = TRUE) &
+      !topic_names %in% c("pipe", "reexports")
   ]
 }
 
@@ -50,7 +50,7 @@ get_example_text <- function(topic) {
 
   topic_names <- names(get_package_docs())
 
-  examples_out <- c()
+  examples_out <- NULL # same as c
 
   for (i in seq_along(topic)) {
 
@@ -73,7 +73,7 @@ get_example_text <- function(topic) {
     }
 
     examples_start_idx <-
-      grep("\\section{Examples}{", help_file_lines, fixed = TRUE) + 1
+      grep("\\section{Examples}{", help_file_lines, fixed = TRUE) + 1L
 
     examples_end_idx <-
       grep(
@@ -91,9 +91,9 @@ get_example_text <- function(topic) {
 
     example_lines <- gsub(".*preformatted.(.*)", "```{r}\n\\1", example_lines)
     example_lines <- gsub("}\\if{html}{\\out{</div>}}", "```", example_lines, fixed = TRUE)
-    example_lines <- example_lines[!grepl("^}|<img", example_lines)]
-    example_lines <- example_lines[!grepl("\\if\\{html\\}", example_lines)]
-    example_lines <- example_lines[!grepl("^#>", example_lines)]
+    example_lines <- grep("^}|<img", example_lines, value = TRUE, invert = TRUE)
+    example_lines <- grep("\\if\\{html\\}", example_lines, value = TRUE, invert = TRUE)
+    example_lines <- grep("^#>", example_lines, value = TRUE, invert = TRUE)
 
     example_lines <- gsub("\\%", "%", example_lines, fixed = TRUE)
     example_lines <- gsub("\\{", "{", example_lines, fixed = TRUE)
@@ -106,12 +106,29 @@ get_example_text <- function(topic) {
     example_lines <- gsub("\\\\code\\{(.*?)\\}", "`\\1`", example_lines)
     example_lines <- gsub("\\\\verb\\{(.*?)\\}", "`\\1`", example_lines)
 
-    example_lines <- example_lines %>% paste(collapse = "\n")
+    example_lines <- paste(example_lines, collapse = "\n")
 
     # Remove leading and trailing whitespace
-    example_lines <- example_lines %>% gsub("^\n\n", "", .)
-    example_lines <- example_lines %>% gsub("\n\n$", "", .)
-    example_lines <- example_lines %>% gsub("\n\n\n", "\n\n", .)
+    example_lines <- gsub("^\n\n", "", example_lines)
+    example_lines <- gsub("\n\n$", "", example_lines)
+    example_lines <- gsub("\n\n\n", "\n\n", example_lines)
+
+    # Replace `\\\\\\\\` with `\\`
+    example_lines <- gsub("\\\\\\\\", "\\", example_lines, fixed = TRUE)
+
+    # Replacements in `text_replace()` example
+    if (topic %in% c("text_replace", "fmt_image")) {
+      example_lines <-
+        gsub("\\((.*?)\\)", "\\\\((.*?)\\\\)", example_lines, fixed = TRUE)
+      example_lines <-
+        gsub("<em>\\1</em>", "<em>\\\\1</em>", example_lines, fixed = TRUE)
+    }
+
+    # Replacements in `fmt_email()` example
+    if (topic == "fmt_email") {
+      example_lines <-
+        gsub("\\(0|\\)", "\\\\(0|\\\\)", example_lines, fixed = TRUE)
+    }
 
     examples_out <- c(examples_out, example_lines)
   }
@@ -177,25 +194,13 @@ write_gt_examples_qmd_files <- function(
 ) {
 
   if (is.null(topics)) {
+    gt_datasets_and_shiny_fns <-
+      c("countrypops", "sza", "gtcars", "sp500", "pizzaplace", "exibble",
+        "towny", "peeps", "films", "metro", "gibraltar", "constants",
+        "illness", "reactions", "photolysis", "nuclides", "rx_adsl",
+        "rx_addv", "render_gt", "gt_output", "fmt_markdown")
 
-    topics <-
-      base::setdiff(
-        get_topic_names(),
-        c(
-          "countrypops",
-          "sza",
-          "gtcars",
-          "sp500",
-          "pizzaplace",
-          "exibble",
-          "towny",
-          "metro",
-          "constants",
-          "illness",
-          "rx_adsl",
-          "rx_addv"
-        )
-      )
+    topics <- base::setdiff(get_topic_names(), gt_datasets_and_shiny_fns)
   }
 
   if (!dir.exists(paths = output_dir)) {
@@ -211,11 +216,11 @@ write_gt_examples_qmd_files <- function(
 
     index_tbl <-
       dplyr::tibble(
-        name = character(0),
-        title = character(0),
-        type = character(0),
-        family = integer(0),
-        number = integer(0)
+        name = character(0L),
+        title = character(0L),
+        type = character(0L),
+        family = integer(0L),
+        number = integer(0L)
       )
 
     pkg_docs <- get_package_docs()
@@ -235,7 +240,7 @@ write_gt_examples_qmd_files <- function(
         family <- as.integer(unlist(strsplit(id_val, split = "-"))[[1]])
         number <- as.integer(unlist(strsplit(id_val, split = "-"))[[2]])
 
-      } else if (any(grepl("Dataset ID ", help_file_lines))) {
+      } else if (any(grepl("Dataset ID ", help_file_lines, fixed = TRUE))) {
 
         type <- "dataset"
         id_idx <- grep("\\section{Dataset ID and Badge}{", help_file_lines, fixed = TRUE) + 2
@@ -266,50 +271,64 @@ write_gt_examples_qmd_files <- function(
       index_tbl <- dplyr::bind_rows(index_tbl, index_tbl_i)
     }
 
-    index_tbl <-
+    index_tbl_gt <-
       index_tbl %>%
       dplyr::arrange(family, number) %>%
       dplyr::mutate(
         name = dplyr::case_when(
           type == "function" ~ paste0(
-            "[`", name, "()`](gt-", name , ".qmd)"
+            "[", name, "()](gt-", name, ".qmd)"
           ),
           .default = name
         )
       ) %>%
       dplyr::mutate(
-        group = dplyr::case_when(
-          family == 1 ~ "Table creation",
-          family == 2 ~ "Creating or modifying parts of a table",
-          family == 3 ~ "Formatting column data",
-          family == 4 ~ "Text transformation",
-          family == 5 ~ "Modifying columns",
-          family == 6 ~ "Adding or modifying rows",
-          family == 7 ~ "Removing parts of a table",
-          family == 8 ~ "Helper functions",
-          family == 9 ~ "Image addition utilities",
-          family == 10 ~ "Table options",
-          family == 11 ~ "Informational tables for reference",
-          family == 12 ~ "Shiny",
-          family == 13 ~ "Export and extraction functions",
-          family == 14 ~ "Working with table groups",
-          family == 15 ~ "Vector formatting",
-          family == 99 ~ "Built in datasets"
+        group = dplyr::case_match(family,
+          1 ~ "Table creation",
+          2 ~ "Creating or modifying parts of a table",
+          3 ~ "Formatting column data",
+          4 ~ "Text transformation",
+          5 ~ "Modifying columns",
+          6 ~ "Adding or modifying rows",
+          7 ~ "Removing parts of a table",
+          8 ~ "Helper functions",
+          9 ~ "Image addition utilities",
+          10 ~ "Table options",
+          11 ~ "Informational tables for reference",
+          12 ~ "Shiny",
+          13 ~ "Export and extraction functions",
+          14 ~ "Working with table groups",
+          15 ~ "Vector formatting",
+          99 ~ "Built in datasets"
         )
       ) %>%
       gt(groupname_col = "group", process_md = TRUE) %>%
       fmt_markdown() %>%
+      fmt_url(columns = name, color = "#045AA2", target = "_self") %>%
       cols_hide(columns = c(type, family, number)) %>%
+      tab_style(
+        style = cell_text(
+          font = system_fonts("monospace-code"),
+          weight = 500
+        ),
+        locations = cells_body(columns = name)
+      ) %>%
       tab_options(column_labels.hidden = TRUE)
 
     writeLines(
       text = c(
         "---",
         "format: html",
+        "html-table-processing: none",
         "---",
         "",
+        paste("The **gt** package has", nrow(index_tbl), "functions."),
+        "Each of these functions has documentation filled with examples.",
+        "The table below organizes all of the functions into families and ",
+        "links to separate pages of **gt** table examples by function.",
+        "",
         "```{=html}",
-        as_raw_html(index_tbl),
+        as_raw_html(index_tbl_gt),
         "```",
         ""
       ),
@@ -320,14 +339,16 @@ write_gt_examples_qmd_files <- function(
       text = c(
         "project:",
         "  type: website",
+        "",
         "render:",
         "  - \"*.qmd\"",
         "",
         "website:",
         "  title: \"The gt package\"",
-        "navbar:",
-        "  left:",
-        "  - href: index.qmd",
+        "  navbar:",
+        "    left:",
+        "    - text: \"home\"",
+        "      file: index.qmd",
         "",
         "format:",
         "  html:",
@@ -344,6 +365,7 @@ write_gt_examples_qmd_files <- function(
       text = c(
         "---",
         "format: html",
+        "html-table-processing: none",
         "toc: false",
         "---",
         "",
@@ -358,6 +380,16 @@ write_gt_examples_qmd_files <- function(
       con = paste0(output_dir, "/gt-", topic, ".qmd")
     )
   }
+
+  writeLines(
+    text = c(
+      "- source: project",
+      "  connect:",
+      "    - id: b5709bdb-5712-42db-b265-2bfa02b5ffb6"#,
+      #"    - url: https://colorado.posit.co/rsc/content/b5709bdb-5712-42db-b265-2bfa02b5ffb6/"
+    ),
+    con = paste0(output_dir, "/_publish.yml")
+  )
 }
 
 #nocov end
