@@ -403,8 +403,7 @@ parse_length_str <- function(
 
     cli::cli_abort(c(
       "Some of the values supplied cannot be interpreted.",
-      "*" = "Problem values are:
-      {str_catalog(bad_values, surround = c('\"'))}.",
+      "*" = "Problem values are: {.str {bad_values}}",
       "*" = "Use either of: `px`, `pt`, `in`, `cm`, `mm`, or `tw`
       (e.g., \"12px\")"
     ))
@@ -807,7 +806,7 @@ footnote_mark_to_rtf <- function(
     rtf_raw(
       paste0(
       "{",
-      if (grepl("\\^", spec)) "\\super " else NULL,
+      if (grepl("^", spec, fixed = TRUE)) "\\super " else NULL,
       if (grepl("i", spec, fixed = TRUE)) "\\i " else NULL,
       if (grepl("b", spec, fixed = TRUE)) "\\b " else NULL
       )
@@ -1019,14 +1018,13 @@ create_heading_component_rtf <- function(data) {
 
   # Obtain widths for each visible column label
   col_widths <-
-    boxh %>%
-    dplyr::filter(type %in% c("default", "stub")) %>%
-    dplyr::arrange(dplyr::desc(type)) %>%
-    dplyr::pull(column_width) %>%
-    unlist()
+    vctrs::vec_slice(boxh, boxh$type %in% c("default", "stub"))
+  # arrange by descending type and grab the "column_width" column.
+  col_widths <- col_widths[order(col_widths$type, decreasing = TRUE), "column_width", drop = TRUE]
+  col_widths <- unlist(col_widths)
 
   if (is.null(col_widths)) {
-     n_cols <- nrow(dplyr::filter(boxh, type %in% c("default", "stub")))
+     n_cols <- sum(boxh$type %in% c("default", "stub"))
      col_widths <- rep("100%", n_cols)
   }
 
@@ -1048,14 +1046,12 @@ create_heading_component_rtf <- function(data) {
 
   if ("title" %in% footnotes_tbl$locname) {
     footnote_title_marks <- coalesce_marks(fn_tbl = footnotes_tbl, locname = "title")
-    footnote_title_marks <- footnote_title_marks$fs_id_c
   } else {
     footnote_title_marks <- ""
   }
 
   if ("subtitle" %in% footnotes_tbl$locname) {
     footnote_subtitle_marks <- coalesce_marks(fn_tbl = footnotes_tbl, locname = "subtitle")
-    footnote_subtitle_marks <- footnote_subtitle_marks$fs_id_c
   } else {
     footnote_subtitle_marks <- ""
   }
@@ -1085,7 +1081,7 @@ create_heading_component_rtf <- function(data) {
   if (
     dt_heading_has_preheader(data = data) &&
     !dt_options_get_value(data, option = "page_numbering")
-    ) {
+  ) {
 
     # Case where one or more preheader lines are present
 
@@ -1193,9 +1189,11 @@ create_columns_component_rtf <- function(data) {
 
   stubh <- dt_stubhead_get(data = data)
 
+  boxh <- dt_boxhead_get(data = data)
   # Get vector representation of stub layout
   stub_layout <- get_stub_layout(data = data)
 
+
   # Determine the finalized number of spanner rows
   spanner_row_count <-
     dt_spanners_matrix_height(
@@ -1213,16 +1211,19 @@ create_columns_component_rtf <- function(data) {
   col_alignment <- dt_boxhead_get_vars_align_default(data = data)
 
   # Obtain widths for each visible column label in units of twips
+  col_widths <- vctrs::vec_slice(
+    boxh,
+    boxh$type %in% c("default", "stub")
+  )
+  # Sort the data frame by desc(type) and get the "column_width" column.
+  col_widths <- col_widths[order(col_widths$type, decreasing = TRUE), "column_width", drop = TRUE]
+  col_widths <- unlist(col_widths)
+
   col_widths <-
-    dt_boxhead_get(data = data) %>%
-    dplyr::filter(type %in% c("default", "stub")) %>%
-    dplyr::arrange(dplyr::desc(type)) %>%
-    dplyr::pull(column_width) %>%
-    unlist() %>%
     col_width_resolver_rtf(
       page_body_width = page_body_width,
       table_width = dt_options_get_value(data = data, option = "table_width"),
-      col_widths = .,
+      col_widths = col_widths,
       n_cols = get_effective_number_of_columns(data = data)
     )
 
@@ -1269,9 +1270,9 @@ create_columns_component_rtf <- function(data) {
           h_merge = merge_keys_cells[x],
           borders = list(
             rtf_border("bottom", color = column_labels_border_bottom_color, width = 20)#,
-          # rtf_border("top", color = column_labels_border_top_color, width = 40),
-          # rtf_border("left", color = column_labels_vlines_color),
-          # rtf_border("right", color = column_labels_vlines_color)
+            # rtf_border("top", color = column_labels_border_top_color, width = 40),
+            # rtf_border("left", color = column_labels_vlines_color),
+            # rtf_border("right", color = column_labels_vlines_color)
           )
         )
       }
@@ -1441,6 +1442,7 @@ create_body_component_rtf <- function(data) {
   # column names for the table
   default_vars <- dt_boxhead_get_vars_labels_default(data = data)
 
+  boxh <- dt_boxhead_get(data)
   # Create a named vector  https://github.com/rstudio/gt/issues/1233
   default_vars_names <-  dt_boxhead_get_vars_default(data = data)
   names(default_vars_names) <- default_vars
@@ -1472,16 +1474,19 @@ create_body_component_rtf <- function(data) {
   n_rows <- nrow(cell_matrix)
 
   # Obtain widths for each visible column label in units of twips
+
+  # Obtain widths for each visible column label
+  col_widths <-
+    vctrs::vec_slice(boxh, boxh$type %in% c("default", "stub"))
+  # arrange by descending type and grab the "column_width" column.
+  col_widths <- col_widths[order(col_widths$type, decreasing = TRUE), "column_width", drop = TRUE]
+  col_widths <- unlist(col_widths)
+
   col_widths <-
-    dt_boxhead_get(data = data) %>%
-    dplyr::filter(type %in% c("default", "stub")) %>%
-    dplyr::arrange(dplyr::desc(type)) %>%
-    dplyr::pull(column_width) %>%
-    unlist() %>%
     col_width_resolver_rtf(
       page_body_width = page_body_width,
       table_width = table_width,
-      col_widths = .,
+      col_widths = col_widths,
       n_cols = n_cols
     )
 
@@ -1625,7 +1630,7 @@ create_body_component_rtf <- function(data) {
 
       group_id <-
         groups_rows_df[
-          stats::na.omit(groups_rows_df$row_end == i),
+          omit_na(groups_rows_df$row_end == i),
           "group_id", drop = TRUE
         ]
 
@@ -1807,14 +1812,14 @@ create_footer_component_rtf <- function(data) {
 
   # Obtain widths for each visible column label
   col_widths <-
-    dplyr::filter(boxh, type %in% c("default", "stub")) %>%
-    dplyr::arrange(dplyr::desc(type)) %>%
-    dplyr::pull(column_width) %>%
-    unlist()
+    vctrs::vec_slice(boxh, boxh$type %in% c("default", "stub"))
+  # arrange by descending type and grab the "column_width" column.
+  col_widths <- col_widths[order(col_widths$type, decreasing = TRUE), "column_width", drop = TRUE]
+  col_widths <- unlist(col_widths)
 
   if (is.null(col_widths)) {
 
-    n_cols <- nrow(dplyr::filter(boxh, type %in% c("default", "stub")))
+    n_cols <- sum(boxh$type %in% c("default", "stub"))
     col_widths <- rep("100%", n_cols)
   }
 
