@@ -53,7 +53,7 @@ test_that("cols_width() stores values correctly", {
       .$`_boxhead` %>%
       dplyr::select(var, column_width) %>%
       dplyr::mutate(column_width = unlist(column_width)),
-    dplyr::tibble(
+    vctrs::data_frame(
       var = paste0("col_", 1:4),
       column_width = paste0((1:4 * 100), "px")
     )
@@ -70,7 +70,7 @@ test_that("cols_width() stores values correctly", {
       .$`_boxhead` %>%
       dplyr::select(var, column_width) %>%
       dplyr::mutate(column_width = unlist(column_width)),
-    dplyr::tibble(
+    vctrs::data_frame(
       var = paste0("col_", 1:4),
       column_width = paste0((1:4 * 100), "px")
     )
@@ -86,7 +86,7 @@ test_that("cols_width() stores values correctly", {
       .$`_boxhead` %>%
       dplyr::select(var, column_width) %>%
       dplyr::mutate(column_width = unlist(column_width)),
-    dplyr::tibble(
+    vctrs::data_frame(
       var = paste0("col_", 1:4),
       column_width = c("100px", "200px", "", "400px")
     )
@@ -100,7 +100,7 @@ test_that("cols_width() stores values correctly", {
       .$`_boxhead` %>%
       dplyr::select(var, column_width) %>%
       dplyr::mutate(column_width = unlist(column_width)),
-    dplyr::tibble(
+    vctrs::data_frame(
       var = paste0("col_", 1:4),
       column_width = "100px"
     )
@@ -114,7 +114,7 @@ test_that("cols_width() stores values correctly", {
       .$`_boxhead` %>%
       dplyr::select(var, column_width) %>%
       dplyr::mutate(column_width = unlist(column_width)),
-    dplyr::tibble(
+    vctrs::data_frame(
       var = paste0("col_", 1:4),
       column_width = "100px"
     )
@@ -135,7 +135,7 @@ test_that("cols_width() stores values correctly", {
       .$`_boxhead` %>%
       dplyr::select(var, column_width) %>%
       dplyr::mutate(column_width = unlist(column_width)),
-    dplyr::tibble(
+    vctrs::data_frame(
       var = c(paste0("col_", 1:4), "row", "group"),
       column_width = c(paste0((1:4 * 100), "px"), "400px", "400px")
     )
@@ -152,7 +152,7 @@ test_that("cols_width() stores values correctly", {
       .$`_boxhead` %>%
       dplyr::select(var, column_width) %>%
       dplyr::mutate(column_width = unlist(column_width)),
-    dplyr::tibble(
+    vctrs::data_frame(
       var = c(paste0("col_", 1:4), "row", "group"),
       column_width = c("100px", "200px", "", "400px", "50px", "")
     )
@@ -166,7 +166,7 @@ test_that("cols_width() stores values correctly", {
       .$`_boxhead` %>%
       dplyr::select(var, column_width) %>%
       dplyr::mutate(column_width = unlist(column_width)),
-    dplyr::tibble(
+    vctrs::data_frame(
       var = c(paste0("col_", 1:4), "row", "group"),
       column_width = rep("100px", 6)
     )
@@ -181,7 +181,7 @@ test_that("cols_width() stores values correctly", {
       .$`_boxhead` %>%
       dplyr::select(var, column_width) %>%
       dplyr::mutate(column_width = unlist(column_width)),
-    dplyr::tibble(
+    vctrs::data_frame(
       var = c(paste0("col_", 1:4), "row", "group"),
       column_width = c(rep("100px", 5), "50px")
     )
@@ -201,7 +201,7 @@ test_that("cols_width() stores values correctly", {
       .$`_boxhead` %>%
       dplyr::select(var, column_width) %>%
       dplyr::mutate(column_width = unlist(column_width)),
-    dplyr::tibble(
+    vctrs::data_frame(
       var = c(paste0("col_", 1:4), "row", "group"),
       column_width = c(rep("100px", 5), "20px")
     )
@@ -220,7 +220,7 @@ test_that("cols_width() stores values correctly", {
       .$`_boxhead` %>%
       dplyr::select(var, column_width) %>%
       dplyr::mutate(column_width = unlist(column_width)),
-    dplyr::tibble(
+    vctrs::data_frame(
       var = c(paste0("col_", 1:4), "row", "group"),
       column_width = c(rep("", 4), "30px", "10px")
     )
@@ -933,7 +933,8 @@ test_that("cols_width() correctly specifies LaTeX table when column widths are s
       col_2 ~ pct(30),
       col_3 ~ pct(20),
       col_4 ~ pct(10)
-    )
+    ) %>%
+    tab_options(latex.use_longtable = TRUE)
 
   pct_string <- function(x, unit = '\\\\linewidth') {
 
@@ -977,11 +978,10 @@ test_that("cols_width() correctly specifies LaTeX table when column widths are s
     )
 
   # Expect that all column widths are expressed as percentage of \linewidth
-  c(0.5, 0.3, 0.2, 0.1) %>%
-    pct_string() %>%
-    build_longtable_regex() %>%
-    grepl(as_latex(tbl_latex)) %>%
-    expect_true()
+  longtable_s <- build_longtable_regex(
+    pct_string(c(0.5, 0.3, 0.2, 0.1))
+  )
+  expect_match(as_latex(tbl_latex), longtable_s)
 
 
   # Check that LaTeX is correctly generated when only some
@@ -991,7 +991,8 @@ test_that("cols_width() correctly specifies LaTeX table when column widths are s
     cols_width(
       col_1 ~ pct(30),
       col_3 ~ pct(20)
-    )
+    ) %>%
+    tab_options(latex.use_longtable = TRUE)
 
   c(
     pct_string(0.3),
@@ -1039,7 +1040,7 @@ test_that("column widths are accurately reflected in Latex multicolumn statement
                n = runif(5),
                w = runif(5))
 
-  gt(tbl_random1,
+  gt_tbl <- gt(tbl_random1,
      rowname_col = 'x',
      row_group_as_column = FALSE) %>%
     fmt_number(decimals = 3) %>%
@@ -1049,12 +1050,8 @@ test_that("column widths are accurately reflected in Latex multicolumn statement
     tab_spanner(label = 'Spanner with a long title that should be wrapped', columns = c('y', 'z')) %>%
     tab_spanner(label = 'Spanner2', columns = c('n', 'w')) %>%
     tab_spanner(label = 'Another long spanner that needs to wrap even more than the other', columns = c('z', 'm')) %>%
-    summary_rows(fns = list("mean")) %>%
-    as_latex() %>%
-    expect_snapshot()
+    summary_rows(fns = list("mean"))
 
+  expect_snapshot(as_latex(gt_tbl))
 
 })
-
-
-
