@@ -1,7 +1,4 @@
-# Create a shortened version of `mtcars`
-mtcars_short <- mtcars[1:5, ]
-
-test_that("The `cols_move()` function works correctly", {
+test_that("cols_move() works correctly", {
 
   # Create a `tbl_latex` object with `gt()`; the `mpg`,
   # `cyl`, and `drat` columns placed after `drat`
@@ -40,7 +37,7 @@ test_that("The `cols_move()` function works correctly", {
   )
 })
 
-test_that("The `cols_move_to_start()` function works correctly", {
+test_that("cols_move_to_start() works correctly", {
 
   # Create a `tbl_latex` object with `gt()`; the `gear`,
   # and `carb` columns placed at the start
@@ -67,7 +64,7 @@ test_that("The `cols_move_to_start()` function works correctly", {
     )
 })
 
-test_that("The `cols_move_to_end()` function works correctly", {
+test_that("cols_move_to_end() works correctly", {
 
   # Create a `tbl_latex` object with `gt()`; the `gear`,
   # and `carb` columns placed at the end
